package com.anyway.favor.controller;

import com.anyway.favor.model.FavorItem;
import com.anyway.favor.model.User;
import com.anyway.favor.model.vo.FavorItemVo;
import com.anyway.favor.service.FavorItemService;
import com.anyway.favor.service.FavorService;
import com.anyway.favor.service.GiftService;
import com.anyway.favor.service.PersonService;
import com.anyway.util.PageQuery;
import com.anyway.util.R;
import com.anyway.util.SessionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.constraints.NotBlank;
import java.util.*;
import java.util.stream.Collectors;

/**
 * 人情明细控制器
 *
 * @author liuchuanwei
 * @date 2024-02-24
 */
@RestController
@RequestMapping("/favorItem")
public class FavorItemController {
    @Autowired
    private FavorItemService favorItemService;
    @Autowired
    private PersonService personService;
    @Autowired
    private FavorService favorService;
    @Autowired
    private GiftService giftService;
    /**
     * 人情明细分页
     *
     * @param pageQuery
     * @return
     */
    @GetMapping("/listPage")
    public R<List<FavorItemVo>> listPage(@RequestBody PageQuery<Map<String, Object>> pageQuery) {
        User currentUser = SessionUtils.currentUser();
        Map<String, Object> mapCondition = pageQuery.getTerms(new HashMap<>());
        //查询和当前登录用户相关的人员
        mapCondition.put("createBy", currentUser.getId());
        mapCondition.put("sortName", "id");
        mapCondition.put("sortOrder", "asc");
        List<FavorItem> favorItemList = favorItemService.findPage(pageQuery);
        //补充人情明细的关联信息
        List<FavorItemVo> favorItemVoList = new ArrayList<>();
        for (FavorItem favorItem : favorItemList) {
            FavorItemVo favorItemVo = new FavorItemVo(favorItem);
            favorItemVo.setFavor(favorService.findById(favorItem.getFavorId()));
            favorItemVo.setHoldPerson(personService.findById(favorItemVo.getFavor().getHoldPersonId()));
            favorItemVo.setReceivePerson(personService.findById(favorItem.getReceivePersonId()));
            favorItemVo.setReturnGift(giftService.findById(favorItem.getReturnGiftId()));
            favorItemVo.setGivePerson(personService.findById(favorItem.getGivePersonId()));
            favorItemVo.setGiveGift(giftService.findById(favorItem.getGiveGiftId()));
            favorItemVoList.add(favorItemVo);
        }
        return R.page(favorItemVoList, pageQuery.getPage());
    }

    /**
     * 批量删除
     *
     * @param ids
     * @return
     */
    @PostMapping("/delete")
    public R<Boolean> delete(@RequestParam @NotBlank(message = "ids不能为空") String ids) {
        String[] arr = ids.split(",");
        List<Long> idList = Arrays.stream(arr).map(Long::valueOf).collect(Collectors.toList());
        boolean b = favorItemService.deleteByIds(idList);
        return b ? R.ok() : R.fail("删除失败");
    }

}
