package com.anyway.favor.dao;

import com.anyway.favor.model.FavorItem;
import com.anyway.favor.model.dto.FavorItemDto;
import org.apache.ibatis.annotations.Param;

import java.util.Collection;
import java.util.List;
import java.util.Map;

/**
 * 人情明细数据层
 *
 * @author liuchuanwei
 * @date 2024-02-24
 */
public interface FavorItemDao {
    /**
     * 查询全部
     *
     * @return
     */
    List<FavorItem> findAll();

    /**
     * 根据条件查询列表
     *
     * @param map
     * @return
     */
    List<FavorItem> findByCondition(Map<String, Object> map);

    /**
     * 根据人情事件查询列表
     *
     * @param favorId
     * @return
     */
    List<FavorItemDto> findByFavorId(Long favorId);

    /**
     * 根据主键ID查询
     *
     * @param id
     * @return
     */
    FavorItem findById(Long id);

    /**
     * 根据主键ID集合查询
     *
     * @param id
     * @return
     */
    List<FavorItem> findByIds(Collection<Long> id);

    /**
     * 插入
     *
     * @param favorItemList
     * @return
     */
    int batchAdd(@Param("favorItemList") List<FavorItem> favorItemList);

    /**
     * 更新
     *
     * @param favorItem
     * @return
     */
    int update(FavorItem favorItem);

    /**
     * 根据ID删除
     *
     * @param id
     * @return
     */
    int deleteById(Long id);


    /**
     * 根据ID集合删除
     *
     * @param ids
     * @return
     */
    int deleteByIds(@Param("ids") Collection<Long> ids);
    /**
     * 根据人情ID删除
     *
     * @param favorId
     * @return
     */
    int deleteByFavorId(Long favorId);

}
