package com.anyway.favor.model;

import com.anyway.favor.model.enums.Update;
import com.fasterxml.jackson.annotation.JsonFormat;
import lombok.Getter;
import lombok.Setter;
import org.springframework.format.annotation.DateTimeFormat;

import javax.validation.constraints.Min;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 人情实体类
 *
 * @author anyway
 * @date 2024-02-20
 */
@Setter
@Getter
public class Favor extends BaseModel implements java.io.Serializable {
    /** 版本号 */
    private static final long serialVersionUID = 666680999611094083L;
    /** id */
    @NotNull(message = "事件id不能为空", groups = {Update.class})
    private Long id;
    /** 举办日期 */
    @NotNull(message = "举办日期不能为空")
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date holdDate;
    /** 标题 */
    @NotBlank(message = "事件标题不能为空")
    private String title;
    /** 举办人 */
    @NotNull(message = "举办人不能为空")
    private Long holdPersonId;
    /** 收入金额 */
    @Min(value = 0, message = "收入金额不能小于0")
    private BigDecimal incomeAmount;
    /** 支出金额 */
    @Min(value = 0, message = "支出金额不能小于0")
    private BigDecimal payAmount;
    /** 备注 */
    private String remark;
}
