package com.anyway.favor.service.impl;

import com.anyway.favor.dao.FavorItemDao;
import com.anyway.favor.dao.GiftDao;
import com.anyway.favor.model.FavorItem;
import com.anyway.favor.model.dto.FavorItemDto;
import com.anyway.favor.service.FavorItemService;
import com.anyway.util.PageQuery;
import com.anyway.util.PageUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;

import java.util.*;

/**
 * 人情明细业务实现类
 *
 * @author liuchuanwei
 * @date 2024-02-24
 */
@Slf4j
@Service
public class FavorItemServiceImpl implements FavorItemService {
    @Autowired
    private FavorItemDao favorItemDao;
    @Autowired
    private GiftDao giftDao;

    @Override
    public List<FavorItem> findByCondition(Map<String, Object> map) {
        return favorItemDao.findByCondition(map);
    }
    @Override
    public List<FavorItem> findPage(PageQuery<Map<String, Object>> pageQuery) {
        PageUtils.startPage(pageQuery.getPage());
        List<FavorItem> favorItemList = favorItemDao.findByCondition(pageQuery.getTerms());
        PageUtils.setPageTotal(favorItemList, pageQuery.getPage());
        return favorItemList;
    }

    @Override
    public List<FavorItem> findByFavorId(Long favorId) {
        Map<String, Object> map = new HashMap<>();
        map.put("favorId", favorId);
        if (!map.containsKey("sortName")) {
            map.put("sortName", "create_time");
            map.put("sortOrder", "asc");
        }
        return favorItemDao.findByCondition(map);
    }

    @Override
    public boolean add(FavorItem favorItem) {
        return false;
    }

    @Override
    public boolean update(FavorItem favorItem) {
        return false;
    }

    @Override
    public FavorItem findById(Long id) {
        return null;
    }

    @Transactional
    @Override
    public boolean deleteByIds(List<Long> ids) {
        List<FavorItem> favorItemList = favorItemDao.findByIds(ids);
        return this.batchDelete(favorItemList);
    }

    @Transactional
    @Override
    public boolean deleteByFavorId(Long favorId) {
        List<FavorItemDto> favorItemDtoList = favorItemDao.findByFavorId(favorId);
        return this.batchDelete(favorItemDtoList);
    }

    @Transactional
    @Override
    public boolean batchDelete(List<? extends FavorItem> favorItemList) {
        if(CollectionUtils.isEmpty(favorItemList)) {
            log.warn("删除失败，人情明细列表为空");
            return false;
        }
        Set<Long> favorItemIdSet = new HashSet<>();
        //删除礼物
        Set<Long> giftIdSet = new HashSet<>();
        for (FavorItem favorItem : favorItemList) {
            favorItemIdSet.add(favorItem.getId());
            giftIdSet.add(favorItem.getGiveGiftId());
            if (favorItem.getReturnGiftId() != null) {
                giftIdSet.add(favorItem.getReturnGiftId());
            }
        }
        giftDao.deleteByIds(giftIdSet);
        int r = favorItemDao.deleteByIds(favorItemIdSet);
        if (r <= 0) {
            log.error("人情明细删除失败：{}", favorItemIdSet);
            return false;
        }
        return true;
    }
}
