package com.anyway.util;

import lombok.Getter;
import lombok.Setter;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import java.util.function.Function;

/**
 * 成对的对象
 *
 * @author liuchuanwei
 * @date 2024-02-21
 */
@Setter
@Getter
public class Pair<L, R> implements Serializable {
    private L key;
    private R value;

    public Pair(L first, R second) {
        this.key = first;
        this.value = second;
    }

    public static <L, R> Pair<L, R> of(L first, R second) {
        return new Pair<>(first, second);
    }
    public static <L, R, T> List<Pair<L, R>> toList(List<T> list, Function<T, L> keyFun, Function<T, R> valueFun) {
        List<Pair<L, R>> pairList = new ArrayList<>();
        for (T t : list) {
            pairList.add(new Pair<>(keyFun.apply(t), valueFun.apply(t)));
        }
        return pairList;
    }
}
