package com.anyway.util;

import lombok.Getter;
import lombok.Setter;

/**
 * 接口返回类
 *
 * @author anyway
 * @date 2024-02-20
 */
@Setter
@Getter
public class R<T> {
    /**
     * 消息码
     */
    private int code;
    /**
     * 消息
     */
    private String msg;
    /**
     * 数据
     */
    private T data;

    /**
     * 分页
     */
    private Page page;
    /**
     * 时间戳
     */
    private long ts = System.currentTimeMillis();

    /**
     * 成功返回
     *
     * @return
     */
    public static <T> R<T> ok() {
        R<T> r = new R<T>();
        r.setCode(0);
        r.setMsg("成功");
        return r;
    }
    /**
     * 失败返回
     *
     * @param msg
     * @return
     */
    public static <T> R<T>fail(String msg) {
        R<T> r = new R<T>();
        r.setCode(1);
        r.setMsg(msg);
        return r;
    }

    /**
     * 失败返回
     *
     * @param code
     * @param msg
     * @return
     */
    public static <T> R<T> fail(int code, String msg) {
        R<T> r = new R<T>();
        r.setCode(code);
        r.setMsg(msg);
        return r;
    }
    /**
     * 成功返回数据
     *
     * @param data
     * @return
     */
    public static <T> R<T> data(T data) {
        R<T> r = new R<T>();
        r.setCode(0);
        r.setMsg("成功");
        r.setData(data);
        return r;
    }

    /**
     * 成功返回分页
     *
     * @param data
     * @param page
     * @return
     */
    public static <T> R<T> page(T data, Page page) {
        R<T> r = new R<T>();
        r.setCode(0);
        r.setMsg("成功");
        r.setData(data);
        r.setPage(page);
        return r;
    }
}
